@@ -13,9 +13,9 @@ from vyper.cli.utils import (
     extract_file_interface_imports,
     get_interface_file_path,
 )
-from vyper.opcodes import DEFAULT_EVM_VERSION, EVM_VERSIONS
-from vyper.parser import parser_utils
-from vyper.settings import VYPER_TRACEBACK_LIMIT
+from vyper.compiler.settings import VYPER_TRACEBACK_LIMIT
+from vyper.evm.opcodes import DEFAULT_EVM_VERSION, EVM_VERSIONS
+from vyper.old_codegen import parser_utils
 from vyper.typing import ContractCodes, ContractPath, OutputFormats
 
 T = TypeVar("T")
@@ -89,6 +89,13 @@ def _parse_args(argv):
         help="Set the traceback limit for error messages reported by the compiler",
         type=int,
     )
+    parser.add_argument(
+        "--debug",
+        help="Turn on compiler debug information. "
+        "Currently an alias for --traceback-limit but "
+        "may add more information in the future",
+        action="store_true",
+    )
     parser.add_argument(
         "--standard-json",
         help="Switch to standard JSON mode. Use `--standard-json -h` for available options.",
@@ -104,6 +111,8 @@ def _parse_args(argv):
         sys.tracebacklimit = args.traceback_limit
     elif VYPER_TRACEBACK_LIMIT is not None:
         sys.tracebacklimit = VYPER_TRACEBACK_LIMIT
+    elif args.debug:
+        sys.tracebacklimit = 1000
     else:
         # Python usually defaults sys.tracebacklimit to 1000.  We use a default
         # setting of zero so error printouts only include information about where
