@@ -3,9 +3,9 @@ import argparse
 import sys
 
 import vyper
-from vyper import compile_lll, optimizer
-from vyper.parser.parser_utils import LLLnode
-from vyper.parser.s_expressions import parse_s_exp
+from vyper.lll import compile_lll, optimizer
+from vyper.lll.s_expressions import parse_s_exp
+from vyper.old_codegen.parser_utils import LLLnode
 
 
 def _parse_cli_args():
